
:autogenerated:

krotov package
==============

.. automodule:: krotov
    


    Submodules:

    .. toctree::
       :maxdepth: 1

       krotov.convergence
       krotov.functionals
       krotov.info_hooks
       krotov.mu
       krotov.objectives
       krotov.optimize
       krotov.propagators
       krotov.pulse_options
       krotov.result
       krotov.shapes
       krotov.structural_conversions



    Summary
    -------

    ``__all__`` Classes:


    .. list-table::
    
       * - :class:`Objective <krotov.objectives.Objective>`
         - A single objective for optimization with Krotov's method
       * - :class:`PulseOptions <krotov.pulse_options.PulseOptions>`
         - Options for the optimization of a control pulse
    

    ``__all__`` Functions:


    .. list-table::
    
       * - :func:`ensemble_objectives <krotov.objectives.ensemble_objectives>`
         - Extend `objectives` for an "ensemble optimization"
       * - :func:`gate_objectives <krotov.objectives.gate_objectives>`
         - Construct a list of objectives for optimizing towards a quantum gate
       * - :func:`optimize_pulses <krotov.optimize.optimize_pulses>`
         - Use Krotov's method to optimize towards the given `objectives`
    


